# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_search_results_dtov2 import ApiSearchResultsDTOV2
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class ComponentSearchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def search_component(
        self,
        stage_id: Annotated[StrictStr, Field(description="Specify the evaluation report stage.")],
        hash: Annotated[Optional[StrictStr], Field(description="Enter the component hash.")] = None,
        component_identifier: Annotated[Optional[ComponentIdentifier], Field(description="Specify the componentIdentifier object containing the format and coordinates.")] = None,
        package_url: Annotated[Optional[StrictStr], Field(description="Enter the packageUrl.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiSearchResultsDTOV2:
        """search_component

        Use this method to retrieve the component details from the application evaluation reports by specifying the component search parameters, format and evaluation stage. You can specify the component search parameters in any one of the 3 ways:<ul><li>SHA1 hash of the component</li><li>Component identifier object containing the coordinates of the component and its format</li><li>packageUrl string</li></ul>Use of wildcards when searching using the GAVEC(coordinates) is supported.  Permissions required: View IQ Elements

        :param stage_id: Specify the evaluation report stage. (required)
        :type stage_id: str
        :param hash: Enter the component hash.
        :type hash: str
        :param component_identifier: Specify the componentIdentifier object containing the format and coordinates.
        :type component_identifier: ComponentIdentifier
        :param package_url: Enter the packageUrl.
        :type package_url: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_component_serialize(
            stage_id=stage_id,
            hash=hash,
            component_identifier=component_identifier,
            package_url=package_url,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiSearchResultsDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_component_with_http_info(
        self,
        stage_id: Annotated[StrictStr, Field(description="Specify the evaluation report stage.")],
        hash: Annotated[Optional[StrictStr], Field(description="Enter the component hash.")] = None,
        component_identifier: Annotated[Optional[ComponentIdentifier], Field(description="Specify the componentIdentifier object containing the format and coordinates.")] = None,
        package_url: Annotated[Optional[StrictStr], Field(description="Enter the packageUrl.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiSearchResultsDTOV2]:
        """search_component

        Use this method to retrieve the component details from the application evaluation reports by specifying the component search parameters, format and evaluation stage. You can specify the component search parameters in any one of the 3 ways:<ul><li>SHA1 hash of the component</li><li>Component identifier object containing the coordinates of the component and its format</li><li>packageUrl string</li></ul>Use of wildcards when searching using the GAVEC(coordinates) is supported.  Permissions required: View IQ Elements

        :param stage_id: Specify the evaluation report stage. (required)
        :type stage_id: str
        :param hash: Enter the component hash.
        :type hash: str
        :param component_identifier: Specify the componentIdentifier object containing the format and coordinates.
        :type component_identifier: ComponentIdentifier
        :param package_url: Enter the packageUrl.
        :type package_url: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_component_serialize(
            stage_id=stage_id,
            hash=hash,
            component_identifier=component_identifier,
            package_url=package_url,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiSearchResultsDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_component_without_preload_content(
        self,
        stage_id: Annotated[StrictStr, Field(description="Specify the evaluation report stage.")],
        hash: Annotated[Optional[StrictStr], Field(description="Enter the component hash.")] = None,
        component_identifier: Annotated[Optional[ComponentIdentifier], Field(description="Specify the componentIdentifier object containing the format and coordinates.")] = None,
        package_url: Annotated[Optional[StrictStr], Field(description="Enter the packageUrl.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """search_component

        Use this method to retrieve the component details from the application evaluation reports by specifying the component search parameters, format and evaluation stage. You can specify the component search parameters in any one of the 3 ways:<ul><li>SHA1 hash of the component</li><li>Component identifier object containing the coordinates of the component and its format</li><li>packageUrl string</li></ul>Use of wildcards when searching using the GAVEC(coordinates) is supported.  Permissions required: View IQ Elements

        :param stage_id: Specify the evaluation report stage. (required)
        :type stage_id: str
        :param hash: Enter the component hash.
        :type hash: str
        :param component_identifier: Specify the componentIdentifier object containing the format and coordinates.
        :type component_identifier: ComponentIdentifier
        :param package_url: Enter the packageUrl.
        :type package_url: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_component_serialize(
            stage_id=stage_id,
            hash=hash,
            component_identifier=component_identifier,
            package_url=package_url,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiSearchResultsDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_component_serialize(
        self,
        stage_id,
        hash,
        component_identifier,
        package_url,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if stage_id is not None:
            
            _query_params.append(('stageId', stage_id))
            
        if hash is not None:
            
            _query_params.append(('hash', hash))
            
        if component_identifier is not None:
            
            _query_params.append(('componentIdentifier', component_identifier))
            
        if package_url is not None:
            
            _query_params.append(('packageUrl', package_url))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/search/component',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.sbom_api import SBOMApi


class TestSBOMApi(unittest.TestCase):
    """SBOMApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SBOMApi()

    def tearDown(self) -> None:
        pass

    def test_delete_sbom_version(self) -> None:
        """Test case for delete_sbom_version

        Delete sbom version
        """
        pass

    def test_delete_vulnerability_analysis(self) -> None:
        """Test case for delete_vulnerability_analysis

        Deletes a Vulnerability analysis for a given component.
        """
        pass

    def test_get_active_sbom_version_list_by_application(self) -> None:
        """Test case for get_active_sbom_version_list_by_application

        Gets a list of active sbom versions by application id
        """
        pass

    def test_get_import_status(self) -> None:
        """Test case for get_import_status

        Get sbom import status
        """
        pass

    def test_get_sbom_components(self) -> None:
        """Test case for get_sbom_components

        Gets the components found in a specific sbom version
        """
        pass

    def test_get_sbom_metadata_summary_for_application(self) -> None:
        """Test case for get_sbom_metadata_summary_for_application

        Gets a paginated list of SBOMs for an application
        """
        pass

    def test_get_sbom_version(self) -> None:
        """Test case for get_sbom_version

        Gets a sbom version
        """
        pass

    def test_get_vulnerability_details(self) -> None:
        """Test case for get_vulnerability_details

        """
        pass

    def test_import_sbom(self) -> None:
        """Test case for import_sbom

        Import a new sbom version
        """
        pass

    def test_save_vulnerability_analysis(self) -> None:
        """Test case for save_vulnerability_analysis

        Updates a vulnerability analysis annotation for a specific SBOM vulnerability
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.epss_data import EpssData
from sonatype_iq_api_client.models.kev_data import KevData
from sonatype_iq_api_client.models.reference_link_dto import ReferenceLinkDTO
from sonatype_iq_api_client.models.root_cause_dto import RootCauseDTO
from sonatype_iq_api_client.models.security_vulnerability_custom_data_dto import SecurityVulnerabilityCustomDataDTO
from sonatype_iq_api_client.models.security_vulnerability_severity_dto import SecurityVulnerabilitySeverityDTO
from sonatype_iq_api_client.models.security_vulnerability_weakness_dto import SecurityVulnerabilityWeaknessDTO
from sonatype_iq_api_client.models.vulnerability_source_dto import VulnerabilitySourceDTO
from typing import Optional, Set
from typing_extensions import Self

class SecurityVulnerabilityDataDTO(BaseModel):
    """
    SecurityVulnerabilityDataDTO
    """ # noqa: E501
    advisories: Optional[List[ReferenceLinkDTO]] = None
    categories: Optional[List[StrictStr]] = None
    component_detection_markdown: Optional[StrictStr] = Field(default=None, alias="componentDetectionMarkdown")
    component_explanation_markdown: Optional[StrictStr] = Field(default=None, alias="componentExplanationMarkdown")
    component_recommendation_markdown: Optional[StrictStr] = Field(default=None, alias="componentRecommendationMarkdown")
    custom_data: Optional[SecurityVulnerabilityCustomDataDTO] = Field(default=None, alias="customData")
    description: Optional[StrictStr] = None
    detection_markdown: Optional[StrictStr] = Field(default=None, alias="detectionMarkdown")
    detection_type: Optional[StrictStr] = Field(default=None, alias="detectionType")
    epss_data: Optional[EpssData] = Field(default=None, alias="epssData")
    explanation_markdown: Optional[StrictStr] = Field(default=None, alias="explanationMarkdown")
    identification_source: Optional[StrictStr] = Field(default=None, alias="identificationSource")
    identifier: Optional[StrictStr] = None
    is_advanced_vulnerability_detection: Optional[StrictBool] = Field(default=None, alias="isAdvancedVulnerabilityDetection")
    kev_data: Optional[KevData] = Field(default=None, alias="kevData")
    main_severity: Optional[SecurityVulnerabilitySeverityDTO] = Field(default=None, alias="mainSeverity")
    recommendation_markdown: Optional[StrictStr] = Field(default=None, alias="recommendationMarkdown")
    research_type: Optional[StrictStr] = Field(default=None, alias="researchType")
    root_causes: Optional[List[RootCauseDTO]] = Field(default=None, alias="rootCauses")
    severity_scores: Optional[List[SecurityVulnerabilitySeverityDTO]] = Field(default=None, alias="severityScores")
    source: Optional[VulnerabilitySourceDTO] = None
    vuln_ids: Optional[List[StrictStr]] = Field(default=None, alias="vulnIds")
    vulnerability_link: Optional[StrictStr] = Field(default=None, alias="vulnerabilityLink")
    vulnerable_version_ranges: Optional[List[StrictStr]] = Field(default=None, alias="vulnerableVersionRanges")
    weakness: Optional[SecurityVulnerabilityWeaknessDTO] = None
    __properties: ClassVar[List[str]] = ["advisories", "categories", "componentDetectionMarkdown", "componentExplanationMarkdown", "componentRecommendationMarkdown", "customData", "description", "detectionMarkdown", "detectionType", "epssData", "explanationMarkdown", "identificationSource", "identifier", "isAdvancedVulnerabilityDetection", "kevData", "mainSeverity", "recommendationMarkdown", "researchType", "rootCauses", "severityScores", "source", "vulnIds", "vulnerabilityLink", "vulnerableVersionRanges", "weakness"]

    @field_validator('research_type')
    def research_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['FAST_TRACK', 'DEEP_DIVE', 'PUBLIC_RESEARCH', 'VENDOR_RESEARCH']):
            raise ValueError("must be one of enum values ('FAST_TRACK', 'DEEP_DIVE', 'PUBLIC_RESEARCH', 'VENDOR_RESEARCH')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SecurityVulnerabilityDataDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in advisories (list)
        _items = []
        if self.advisories:
            for _item_advisories in self.advisories:
                if _item_advisories:
                    _items.append(_item_advisories.to_dict())
            _dict['advisories'] = _items
        # override the default output from pydantic by calling `to_dict()` of custom_data
        if self.custom_data:
            _dict['customData'] = self.custom_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of epss_data
        if self.epss_data:
            _dict['epssData'] = self.epss_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kev_data
        if self.kev_data:
            _dict['kevData'] = self.kev_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of main_severity
        if self.main_severity:
            _dict['mainSeverity'] = self.main_severity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in root_causes (list)
        _items = []
        if self.root_causes:
            for _item_root_causes in self.root_causes:
                if _item_root_causes:
                    _items.append(_item_root_causes.to_dict())
            _dict['rootCauses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in severity_scores (list)
        _items = []
        if self.severity_scores:
            for _item_severity_scores in self.severity_scores:
                if _item_severity_scores:
                    _items.append(_item_severity_scores.to_dict())
            _dict['severityScores'] = _items
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weakness
        if self.weakness:
            _dict['weakness'] = self.weakness.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SecurityVulnerabilityDataDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "advisories": [ReferenceLinkDTO.from_dict(_item) for _item in obj["advisories"]] if obj.get("advisories") is not None else None,
            "categories": obj.get("categories"),
            "componentDetectionMarkdown": obj.get("componentDetectionMarkdown"),
            "componentExplanationMarkdown": obj.get("componentExplanationMarkdown"),
            "componentRecommendationMarkdown": obj.get("componentRecommendationMarkdown"),
            "customData": SecurityVulnerabilityCustomDataDTO.from_dict(obj["customData"]) if obj.get("customData") is not None else None,
            "description": obj.get("description"),
            "detectionMarkdown": obj.get("detectionMarkdown"),
            "detectionType": obj.get("detectionType"),
            "epssData": EpssData.from_dict(obj["epssData"]) if obj.get("epssData") is not None else None,
            "explanationMarkdown": obj.get("explanationMarkdown"),
            "identificationSource": obj.get("identificationSource"),
            "identifier": obj.get("identifier"),
            "isAdvancedVulnerabilityDetection": obj.get("isAdvancedVulnerabilityDetection"),
            "kevData": KevData.from_dict(obj["kevData"]) if obj.get("kevData") is not None else None,
            "mainSeverity": SecurityVulnerabilitySeverityDTO.from_dict(obj["mainSeverity"]) if obj.get("mainSeverity") is not None else None,
            "recommendationMarkdown": obj.get("recommendationMarkdown"),
            "researchType": obj.get("researchType"),
            "rootCauses": [RootCauseDTO.from_dict(_item) for _item in obj["rootCauses"]] if obj.get("rootCauses") is not None else None,
            "severityScores": [SecurityVulnerabilitySeverityDTO.from_dict(_item) for _item in obj["severityScores"]] if obj.get("severityScores") is not None else None,
            "source": VulnerabilitySourceDTO.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "vulnIds": obj.get("vulnIds"),
            "vulnerabilityLink": obj.get("vulnerabilityLink"),
            "vulnerableVersionRanges": obj.get("vulnerableVersionRanges"),
            "weakness": SecurityVulnerabilityWeaknessDTO.from_dict(obj["weakness"]) if obj.get("weakness") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.system_config_property import SystemConfigProperty

class TestSystemConfigProperty(unittest.TestCase):
    """SystemConfigProperty unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSystemConfigProperty(self):
        """Test SystemConfigProperty"""
        # inst = SystemConfigProperty()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_component_details_dtov2 import ApiComponentDetailsDTOV2

class TestApiComponentDetailsDTOV2(unittest.TestCase):
    """ApiComponentDetailsDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiComponentDetailsDTOV2:
        """Test ApiComponentDetailsDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiComponentDetailsDTOV2`
        """
        model = ApiComponentDetailsDTOV2()
        if include_optional:
            return ApiComponentDetailsDTOV2(
                catalog_date = '',
                component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        coordinates = {
                            'key' : ''
                            }, 
                        format = '', ), 
                    display_name = '', 
                    hash = '', 
                    package_url = '', 
                    proprietary = True, 
                    sha256 = '', 
                    third_party = True, ),
                hygiene_rating = '',
                integrity_rating = '',
                license_data = sonatype_iq_api_client.models.api_license_data_dto.ApiLicenseDataDTO(
                    declared_licenses = [
                        sonatype_iq_api_client.models.api_license_dto.ApiLicenseDTO(
                            license_id = '', 
                            license_name = '', )
                        ], 
                    effective_licenses = [
                        sonatype_iq_api_client.models.api_license_dto.ApiLicenseDTO(
                            license_id = '', 
                            license_name = '', )
                        ], 
                    observed_licenses = [
                        
                        ], 
                    overridden_licenses = [
                        
                        ], 
                    status = '', ),
                match_state = '',
                policy_data = sonatype_iq_api_client.models.api_component_policy_violation_list_dtov2.ApiComponentPolicyViolationListDTOV2(
                    policy_violations = [
                        sonatype_iq_api_client.models.api_policy_violation_dtov2.ApiPolicyViolationDTOV2(
                            constraint_violations = [
                                sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                    constraint_id = '', 
                                    constraint_name = '', 
                                    reasons = [
                                        sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                            reason = '', 
                                            reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                type = 'SECURITY_VULNERABILITY_REFID', 
                                                value = '', ), )
                                        ], )
                                ], 
                            fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            policy_id = '', 
                            policy_name = '', 
                            policy_violation_id = '', 
                            threat_level = 56, 
                            waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], ),
                project_data = sonatype_iq_api_client.models.api_component_project_data_dto.ApiComponentProjectDataDTO(
                    first_release_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_release_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    project_metadata = sonatype_iq_api_client.models.api_component_project_metadata_dto.ApiComponentProjectMetadataDTO(
                        description = '', 
                        organization = '', ), 
                    source_control_management = sonatype_iq_api_client.models.api_component_project_scm_dto.ApiComponentProjectScmDTO(
                        scm_details = sonatype_iq_api_client.models.api_component_project_scm_details_dto.ApiComponentProjectScmDetailsDTO(
                            commits_per_month = 56, 
                            unique_devs_per_month = 56, ), 
                        scm_metadata = sonatype_iq_api_client.models.api_component_project_scm_metadata_dto.ApiComponentProjectScmMetadataDTO(
                            forks = 56, 
                            stars = 56, ), 
                        scm_url = '', ), ),
                relative_popularity = 56,
                security_data = sonatype_iq_api_client.models.api_security_data_dto.ApiSecurityDataDTO(
                    security_issues = [
                        sonatype_iq_api_client.models.api_security_issue_dto.ApiSecurityIssueDTO(
                            analysis = sonatype_iq_api_client.models.api_security_issue_analysis_dto.ApiSecurityIssueAnalysisDTO(
                                detail = '', 
                                justification = '', 
                                response = '', 
                                state = '', ), 
                            cvss_vector = '', 
                            cvss_vector_source = '', 
                            cwe = '', 
                            reference = '', 
                            severity = 1.337, 
                            source = '', 
                            status = '', 
                            threat_category = '', 
                            url = '', )
                        ], )
            )
        else:
            return ApiComponentDetailsDTOV2(
        )
        """

    def testApiComponentDetailsDTOV2(self):
        """Test ApiComponentDetailsDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO

class TestApiSecurityDataDTO(unittest.TestCase):
    """ApiSecurityDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecurityDataDTO:
        """Test ApiSecurityDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecurityDataDTO`
        """
        model = ApiSecurityDataDTO()
        if include_optional:
            return ApiSecurityDataDTO(
                security_issues = [
                    sonatype_iq_api_client.models.api_security_issue_dto.ApiSecurityIssueDTO(
                        analysis = sonatype_iq_api_client.models.api_security_issue_analysis_dto.ApiSecurityIssueAnalysisDTO(
                            detail = '', 
                            justification = '', 
                            response = '', 
                            state = '', ), 
                        cvss_vector = '', 
                        cvss_vector_source = '', 
                        cwe = '', 
                        reference = '', 
                        severity = 1.337, 
                        source = '', 
                        status = '', 
                        threat_category = '', 
                        url = '', )
                    ]
            )
        else:
            return ApiSecurityDataDTO(
        )
        """

    def testApiSecurityDataDTO(self):
        """Test ApiSecurityDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_report_component_policy_violations_dtov2 import ApiReportComponentPolicyViolationsDTOV2

class TestApiReportComponentPolicyViolationsDTOV2(unittest.TestCase):
    """ApiReportComponentPolicyViolationsDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiReportComponentPolicyViolationsDTOV2:
        """Test ApiReportComponentPolicyViolationsDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiReportComponentPolicyViolationsDTOV2`
        """
        model = ApiReportComponentPolicyViolationsDTOV2()
        if include_optional:
            return ApiReportComponentPolicyViolationsDTOV2(
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                dependency_data = sonatype_iq_api_client.models.api_dependency_data_dto.ApiDependencyDataDTO(
                    direct_dependency = True, 
                    inner_source = True, 
                    inner_source_data = [
                        sonatype_iq_api_client.models.inner_source_data.InnerSourceData(
                            inner_source_component_purl = '', 
                            owner_application_id = '', 
                            owner_application_name = '', )
                        ], 
                    parent_component_purls = [
                        ''
                        ], ),
                display_name = '',
                hash = '',
                match_state = '',
                package_url = '',
                pathnames = [
                    ''
                    ],
                proprietary = True,
                sha256 = '',
                third_party = True,
                violations = [
                    sonatype_iq_api_client.models.api_report_policy_violation_dtov2.ApiReportPolicyViolationDTOV2(
                        constraints = [
                            sonatype_iq_api_client.models.api_report_constraint_violation_dtov2.ApiReportConstraintViolationDTOV2(
                                conditions = [
                                    sonatype_iq_api_client.models.api_report_constraint_condition_dtov2.ApiReportConstraintConditionDTOV2(
                                        condition_reason = '', 
                                        condition_summary = '', )
                                    ], 
                                constraint_id = '', 
                                constraint_name = '', )
                            ], 
                        fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        grandfathered = True, 
                        legacy_violation = True, 
                        legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        policy_id = '', 
                        policy_name = '', 
                        policy_threat_category = '', 
                        policy_threat_level = 56, 
                        policy_violation_id = '', 
                        waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        waived = True, 
                        waived_with_auto_waiver = True, )
                    ]
            )
        else:
            return ApiReportComponentPolicyViolationsDTOV2(
        )
        """

    def testApiReportComponentPolicyViolationsDTOV2(self):
        """Test ApiReportComponentPolicyViolationsDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.config_zscaler_api import ConfigZscalerApi


class TestConfigZscalerApi(unittest.TestCase):
    """ConfigZscalerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigZscalerApi()

    def tearDown(self) -> None:
        pass

    def test_delete_all_categories(self) -> None:
        """Test case for delete_all_categories

        """
        pass

    def test_delete_category(self) -> None:
        """Test case for delete_category

        """
        pass

    def test_delete_configuration6(self) -> None:
        """Test case for delete_configuration6

        """
        pass

    def test_get_configuration6(self) -> None:
        """Test case for get_configuration6

        """
        pass

    def test_get_quota(self) -> None:
        """Test case for get_quota

        """
        pass

    def test_set_configuration6(self) -> None:
        """Test case for set_configuration6

        """
        pass

    def test_test_configuration1(self) -> None:
        """Test case for test_configuration1

        """
        pass

    def test_trigger_update(self) -> None:
        """Test case for trigger_update

        """
        pass

    def test_trigger_update_all(self) -> None:
        """Test case for trigger_update_all

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_component_waivers_dto import ApiComponentWaiversDTO

class TestApiComponentWaiversDTO(unittest.TestCase):
    """ApiComponentWaiversDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiComponentWaiversDTO:
        """Test ApiComponentWaiversDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiComponentWaiversDTO`
        """
        model = ApiComponentWaiversDTO()
        if include_optional:
            return ApiComponentWaiversDTO(
                application_waivers = [
                    sonatype_iq_api_client.models.api_application_waiver_dto.ApiApplicationWaiverDTO(
                        application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                            contact_user_name = '', 
                            id = '', 
                            name = '', 
                            organization_id = '', 
                            public_id = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_policy_violation_stage_dto.ApiPolicyViolationStageDTO(
                                component_policy_violations = [
                                    sonatype_iq_api_client.models.api_component_policy_violation_dto.ApiComponentPolicyViolationDTO(
                                        component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                                coordinates = {
                                                    'key' : ''
                                                    }, 
                                                format = '', ), 
                                            display_name = '', 
                                            hash = '', 
                                            package_url = '', 
                                            proprietary = True, 
                                            sha256 = '', 
                                            third_party = True, ), 
                                        waived_policy_violations = [
                                            sonatype_iq_api_client.models.api_waived_policy_violation_dto.ApiWaivedPolicyViolationDTO(
                                                constraint_violations = [
                                                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                                        constraint_id = '', 
                                                        constraint_name = '', 
                                                        reasons = [
                                                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                                                reason = '', 
                                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                                    value = '', ), )
                                                            ], )
                                                    ], 
                                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                policy_id = '', 
                                                policy_name = '', 
                                                policy_violation_id = '', 
                                                policy_waiver = sonatype_iq_api_client.models.api_policy_waiver_dto.ApiPolicyWaiverDTO(
                                                    associated_package_url = '', 
                                                    comment = '', 
                                                    component_name = '', 
                                                    component_upgrade_available = True, 
                                                    constraint_facts = [
                                                        sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                                            condition_facts = [
                                                                sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                                                    condition_index = 56, 
                                                                    condition_type_id = '', 
                                                                    reason = '', 
                                                                    summary = '', 
                                                                    trigger_json = '', )
                                                                ], 
                                                            constraint_id = '', 
                                                            constraint_name = '', 
                                                            operator_name = '', )
                                                        ], 
                                                    constraint_facts_json = '', 
                                                    create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    creator_id = '', 
                                                    creator_name = '', 
                                                    display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                                        name = '', 
                                                        parts = [
                                                            sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                                                field = '', 
                                                                value = '', )
                                                            ], ), 
                                                    expire_when_remediation_available = True, 
                                                    expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    for_container_image = True, 
                                                    for_container_image_component = True, 
                                                    hash = '', 
                                                    is_obsolete = True, 
                                                    matcher_strategy = 'DEFAULT', 
                                                    policy_id = '', 
                                                    policy_name = '', 
                                                    policy_violation_id = '', 
                                                    policy_waiver_id = '', 
                                                    policy_waiver_reason_id = '', 
                                                    reason_text = '', 
                                                    scope_owner_id = '', 
                                                    scope_owner_name = '', 
                                                    scope_owner_type = '', 
                                                    threat_level = 56, 
                                                    vulnerability_id = '', ), 
                                                threat_level = 56, 
                                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], )
                                    ], 
                                stage_id = '', )
                            ], )
                    ],
                repository_waivers = [
                    sonatype_iq_api_client.models.api_repository_waiver_dto.ApiRepositoryWaiverDTO(
                        repository = sonatype_iq_api_client.models.api_repository_dto.ApiRepositoryDTO(
                            audit_enabled = True, 
                            format = '', 
                            namespace_confusion_protection_enabled = True, 
                            policy_compliant_component_selection_enabled = True, 
                            public_id = '', 
                            quarantine_enabled = True, 
                            repository_id = '', 
                            type = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_policy_violation_stage_dto.ApiPolicyViolationStageDTO(
                                component_policy_violations = [
                                    sonatype_iq_api_client.models.api_component_policy_violation_dto.ApiComponentPolicyViolationDTO(
                                        component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                                coordinates = {
                                                    'key' : ''
                                                    }, 
                                                format = '', ), 
                                            display_name = '', 
                                            hash = '', 
                                            package_url = '', 
                                            proprietary = True, 
                                            sha256 = '', 
                                            third_party = True, ), 
                                        waived_policy_violations = [
                                            sonatype_iq_api_client.models.api_waived_policy_violation_dto.ApiWaivedPolicyViolationDTO(
                                                constraint_violations = [
                                                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                                        constraint_id = '', 
                                                        constraint_name = '', 
                                                        reasons = [
                                                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                                                reason = '', 
                                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                                    value = '', ), )
                                                            ], )
                                                    ], 
                                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                policy_id = '', 
                                                policy_name = '', 
                                                policy_violation_id = '', 
                                                policy_waiver = sonatype_iq_api_client.models.api_policy_waiver_dto.ApiPolicyWaiverDTO(
                                                    associated_package_url = '', 
                                                    comment = '', 
                                                    component_name = '', 
                                                    component_upgrade_available = True, 
                                                    constraint_facts = [
                                                        sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                                            condition_facts = [
                                                                sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                                                    condition_index = 56, 
                                                                    condition_type_id = '', 
                                                                    reason = '', 
                                                                    summary = '', 
                                                                    trigger_json = '', )
                                                                ], 
                                                            constraint_id = '', 
                                                            constraint_name = '', 
                                                            operator_name = '', )
                                                        ], 
                                                    constraint_facts_json = '', 
                                                    create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    creator_id = '', 
                                                    creator_name = '', 
                                                    display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                                        name = '', 
                                                        parts = [
                                                            sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                                                field = '', 
                                                                value = '', )
                                                            ], ), 
                                                    expire_when_remediation_available = True, 
                                                    expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    for_container_image = True, 
                                                    for_container_image_component = True, 
                                                    hash = '', 
                                                    is_obsolete = True, 
                                                    matcher_strategy = 'DEFAULT', 
                                                    policy_id = '', 
                                                    policy_name = '', 
                                                    policy_violation_id = '', 
                                                    policy_waiver_id = '', 
                                                    policy_waiver_reason_id = '', 
                                                    reason_text = '', 
                                                    scope_owner_id = '', 
                                                    scope_owner_name = '', 
                                                    scope_owner_type = '', 
                                                    threat_level = 56, 
                                                    vulnerability_id = '', ), 
                                                threat_level = 56, 
                                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], )
                                    ], 
                                stage_id = '', )
                            ], )
                    ]
            )
        else:
            return ApiComponentWaiversDTO(
        )
        """

    def testApiComponentWaiversDTO(self):
        """Test ApiComponentWaiversDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.component_fact import ComponentFact

class TestComponentFact(unittest.TestCase):
    """ComponentFact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComponentFact:
        """Test ComponentFact
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComponentFact`
        """
        model = ComponentFact()
        if include_optional:
            return ComponentFact(
                component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                constraint_facts = [
                    sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                        condition_facts = [
                            sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                condition_index = 56, 
                                condition_type_id = '', 
                                reason = '', 
                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                    value = '', ), 
                                summary = '', 
                                trigger_json = '', )
                            ], 
                        constraint_id = '', 
                        constraint_name = '', 
                        operator_name = '', )
                    ],
                display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                    name = '', 
                    parts = [
                        sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                            field = '', 
                            value = '', )
                        ], ),
                hash = '',
                pathnames = [
                    ''
                    ]
            )
        else:
            return ComponentFact(
        )
        """

    def testComponentFact(self):
        """Test ComponentFact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_application_categories_dto import ApiApplicationCategoriesDTO

class TestApiApplicationCategoriesDTO(unittest.TestCase):
    """ApiApplicationCategoriesDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationCategoriesDTO:
        """Test ApiApplicationCategoriesDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationCategoriesDTO`
        """
        model = ApiApplicationCategoriesDTO()
        if include_optional:
            return ApiApplicationCategoriesDTO(
                categories = [
                    sonatype_iq_api_client.models.api_application_category_dto.ApiApplicationCategoryDTO(
                        color = '', 
                        description = '', 
                        id = '', 
                        name = '', 
                        organization_id = '', )
                    ],
                contact_user_name = '',
                id = '',
                name = '',
                organization_id = '',
                public_id = ''
            )
        else:
            return ApiApplicationCategoriesDTO(
        )
        """

    def testApiApplicationCategoriesDTO(self):
        """Test ApiApplicationCategoriesDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_license_legal_data_dto import ApiLicenseLegalDataDTO

class TestApiLicenseLegalDataDTO(unittest.TestCase):
    """ApiLicenseLegalDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLicenseLegalDataDTO:
        """Test ApiLicenseLegalDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLicenseLegalDataDTO`
        """
        model = ApiLicenseLegalDataDTO()
        if include_optional:
            return ApiLicenseLegalDataDTO(
                attributions = [
                    sonatype_iq_api_client.models.component_obligation_attribution_dto.ComponentObligationAttributionDTO(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        content = '', 
                        id = '', 
                        last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_updated_by_username = '', 
                        obligation_name = '', 
                        owner_id = '', 
                        package_url = '', )
                    ],
                component_copyright_id = '',
                component_copyright_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                component_copyright_last_updated_by_username = '',
                component_copyright_scope_owner_id = '',
                component_licenses_id = '',
                component_licenses_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                component_licenses_last_updated_by_username = '',
                component_licenses_scope_owner_id = '',
                component_notices_id = '',
                component_notices_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                component_notices_last_updated_by_username = '',
                component_notices_scope_owner_id = '',
                copyrights = [
                    sonatype_iq_api_client.models.api_license_legal_copyright_dto.ApiLicenseLegalCopyrightDTO(
                        content = '', 
                        id = '', 
                        original_content_hash = '', 
                        status = 'enabled', )
                    ],
                declared_licenses = [
                    ''
                    ],
                effective_license_status = '',
                effective_licenses = [
                    ''
                    ],
                highest_effective_license_threat_group = sonatype_iq_api_client.models.api_license_threat_dtov2.ApiLicenseThreatDTOV2(
                    license_threat_group_category = '', 
                    license_threat_group_level = 56, 
                    license_threat_group_name = '', ),
                license_files = [
                    sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                        content = '', 
                        id = '', 
                        original_content_hash = '', 
                        rel_path = '', 
                        status = 'enabled', )
                    ],
                notice_files = [
                    sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                        content = '', 
                        id = '', 
                        original_content_hash = '', 
                        rel_path = '', 
                        status = 'enabled', )
                    ],
                obligations = [
                    sonatype_iq_api_client.models.api_license_legal_obligation_dto.ApiLicenseLegalObligationDTO(
                        comment = '', 
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        id = '', 
                        last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_updated_by_username = '', 
                        name = '', 
                        owner_id = '', 
                        package_url = '', 
                        status = 'OPEN', )
                    ],
                observed_licenses = [
                    ''
                    ],
                source_links = [
                    sonatype_iq_api_client.models.legal_source_link_dto.LegalSourceLinkDTO(
                        content = '', 
                        id = '', 
                        original_content = '', 
                        status = 'enabled', )
                    ]
            )
        else:
            return ApiLicenseLegalDataDTO(
        )
        """

    def testApiLicenseLegalDataDTO(self):
        """Test ApiLicenseLegalDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class VulnerabilityAnalysis(BaseModel):
    """
    Vulnerability analysis details.
    """ # noqa: E501
    created_on: Optional[datetime] = Field(default=None, alias="createdOn")
    detail: StrictStr = Field(description="Detailed description of the impact including methods used during assessment")
    justification: StrictStr = Field(description="The rationale of why the impact analysis state was asserted")
    last_updated_by: Optional[StrictStr] = Field(default=None, alias="lastUpdatedBy")
    last_updated_on: Optional[datetime] = Field(default=None, alias="lastUpdatedOn")
    response: StrictStr = Field(description="Vulnerability analysis response by an author, supplier or manufacturer for the affected component.")
    state: StrictStr = Field(description="Vulnerability analysis state.")
    __properties: ClassVar[List[str]] = ["createdOn", "detail", "justification", "lastUpdatedBy", "lastUpdatedOn", "response", "state"]

    @field_validator('justification')
    def justification_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['code_not_present', 'code_not_reachable', 'requires_configuration', 'requires_dependency', 'requires_environment', 'protected_by_compiler', 'protected_at_runtime', 'protected_at_perimeter', 'protected_by_mitigating_control']):
            raise ValueError("must be one of enum values ('code_not_present', 'code_not_reachable', 'requires_configuration', 'requires_dependency', 'requires_environment', 'protected_by_compiler', 'protected_at_runtime', 'protected_at_perimeter', 'protected_by_mitigating_control')")
        return value

    @field_validator('response')
    def response_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['can_not_fix', 'will_not_fix', 'update', 'rollback', 'workaround_available']):
            raise ValueError("must be one of enum values ('can_not_fix', 'will_not_fix', 'update', 'rollback', 'workaround_available')")
        return value

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['resolved', 'resolved_with_pedigree', 'exploitable', 'in_triage', 'false_positive', 'not_affected']):
            raise ValueError("must be one of enum values ('resolved', 'resolved_with_pedigree', 'exploitable', 'in_triage', 'false_positive', 'not_affected')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VulnerabilityAnalysis from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "created_on",
            "last_updated_by",
            "last_updated_on",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VulnerabilityAnalysis from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdOn": obj.get("createdOn"),
            "detail": obj.get("detail"),
            "justification": obj.get("justification"),
            "lastUpdatedBy": obj.get("lastUpdatedBy"),
            "lastUpdatedOn": obj.get("lastUpdatedOn"),
            "response": obj.get("response"),
            "state": obj.get("state")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_stale_evaluations_dto import ApiStaleEvaluationsDTO

class TestApiStaleEvaluationsDTO(unittest.TestCase):
    """ApiStaleEvaluationsDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiStaleEvaluationsDTO:
        """Test ApiStaleEvaluationsDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiStaleEvaluationsDTO`
        """
        model = ApiStaleEvaluationsDTO()
        if include_optional:
            return ApiStaleEvaluationsDTO(
                applications = [
                    sonatype_iq_api_client.models.api_stale_application_evaluation_dto.ApiStaleApplicationEvaluationDTO(
                        application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                            contact_user_name = '', 
                            id = '', 
                            name = '', 
                            organization_id = '', 
                            public_id = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                stage_id = '', )
                            ], )
                    ],
                repositories = [
                    sonatype_iq_api_client.models.api_stale_repository_evaluation_dto.ApiStaleRepositoryEvaluationDTO(
                        repository = sonatype_iq_api_client.models.api_repository_dto.ApiRepositoryDTO(
                            audit_enabled = True, 
                            format = '', 
                            namespace_confusion_protection_enabled = True, 
                            policy_compliant_component_selection_enabled = True, 
                            public_id = '', 
                            quarantine_enabled = True, 
                            repository_id = '', 
                            type = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                stage_id = '', )
                            ], )
                    ]
            )
        else:
            return ApiStaleEvaluationsDTO(
        )
        """

    def testApiStaleEvaluationsDTO(self):
        """Test ApiStaleEvaluationsDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_component_identifier_dtov2 import ApiComponentIdentifierDTOV2
from sonatype_iq_api_client.models.component_display_name import ComponentDisplayName
from sonatype_iq_api_client.models.constraint_fact import ConstraintFact
from typing import Optional, Set
from typing_extensions import Self

class ApiPolicyWaiverRequestDTO(BaseModel):
    """
    ApiPolicyWaiverRequestDTO
    """ # noqa: E501
    associated_package_url: Optional[StrictStr] = Field(default=None, alias="associatedPackageUrl")
    comment: Optional[StrictStr] = None
    component_identifier: Optional[ApiComponentIdentifierDTOV2] = Field(default=None, alias="componentIdentifier")
    component_name: Optional[StrictStr] = Field(default=None, alias="componentName")
    component_upgrade_available: Optional[StrictBool] = Field(default=None, alias="componentUpgradeAvailable")
    constraint_facts: Optional[List[ConstraintFact]] = Field(default=None, alias="constraintFacts")
    constraint_facts_json: Optional[StrictStr] = Field(default=None, alias="constraintFactsJson")
    display_name: Optional[ComponentDisplayName] = Field(default=None, alias="displayName")
    expire_when_remediation_available: Optional[StrictBool] = Field(default=None, alias="expireWhenRemediationAvailable")
    expiry_time: Optional[datetime] = Field(default=None, alias="expiryTime")
    hash: Optional[StrictStr] = None
    is_obsolete: Optional[StrictBool] = Field(default=None, alias="isObsolete")
    matcher_strategy: Optional[StrictStr] = Field(default=None, alias="matcherStrategy")
    note_to_reviewer: Optional[StrictStr] = Field(default=None, alias="noteToReviewer")
    policy_id: Optional[StrictStr] = Field(default=None, alias="policyId")
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    policy_violation_id: Optional[StrictStr] = Field(default=None, alias="policyViolationId")
    policy_waiver_reason_id: Optional[StrictStr] = Field(default=None, alias="policyWaiverReasonId")
    policy_waiver_request_id: Optional[StrictStr] = Field(default=None, alias="policyWaiverRequestId")
    reason_text: Optional[StrictStr] = Field(default=None, alias="reasonText")
    rejection_reason: Optional[StrictStr] = Field(default=None, alias="rejectionReason")
    request_time: Optional[datetime] = Field(default=None, alias="requestTime")
    requester_id: Optional[StrictStr] = Field(default=None, alias="requesterId")
    requester_name: Optional[StrictStr] = Field(default=None, alias="requesterName")
    reviewer_id: Optional[StrictStr] = Field(default=None, alias="reviewerId")
    reviewer_name: Optional[StrictStr] = Field(default=None, alias="reviewerName")
    scope_owner_id: Optional[StrictStr] = Field(default=None, alias="scopeOwnerId")
    scope_owner_name: Optional[StrictStr] = Field(default=None, alias="scopeOwnerName")
    scope_owner_type: Optional[StrictStr] = Field(default=None, alias="scopeOwnerType")
    status: Optional[StrictStr] = None
    threat_level: Optional[StrictInt] = Field(default=None, alias="threatLevel")
    vulnerability_id: Optional[StrictStr] = Field(default=None, alias="vulnerabilityId")
    __properties: ClassVar[List[str]] = ["associatedPackageUrl", "comment", "componentIdentifier", "componentName", "componentUpgradeAvailable", "constraintFacts", "constraintFactsJson", "displayName", "expireWhenRemediationAvailable", "expiryTime", "hash", "isObsolete", "matcherStrategy", "noteToReviewer", "policyId", "policyName", "policyViolationId", "policyWaiverReasonId", "policyWaiverRequestId", "reasonText", "rejectionReason", "requestTime", "requesterId", "requesterName", "reviewerId", "reviewerName", "scopeOwnerId", "scopeOwnerName", "scopeOwnerType", "status", "threatLevel", "vulnerabilityId"]

    @field_validator('matcher_strategy')
    def matcher_strategy_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DEFAULT', 'EXACT_COMPONENT', 'ALL_COMPONENTS', 'ALL_VERSIONS']):
            raise ValueError("must be one of enum values ('DEFAULT', 'EXACT_COMPONENT', 'ALL_COMPONENTS', 'ALL_VERSIONS')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiPolicyWaiverRequestDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component_identifier
        if self.component_identifier:
            _dict['componentIdentifier'] = self.component_identifier.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in constraint_facts (list)
        _items = []
        if self.constraint_facts:
            for _item_constraint_facts in self.constraint_facts:
                if _item_constraint_facts:
                    _items.append(_item_constraint_facts.to_dict())
            _dict['constraintFacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of display_name
        if self.display_name:
            _dict['displayName'] = self.display_name.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiPolicyWaiverRequestDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "associatedPackageUrl": obj.get("associatedPackageUrl"),
            "comment": obj.get("comment"),
            "componentIdentifier": ApiComponentIdentifierDTOV2.from_dict(obj["componentIdentifier"]) if obj.get("componentIdentifier") is not None else None,
            "componentName": obj.get("componentName"),
            "componentUpgradeAvailable": obj.get("componentUpgradeAvailable"),
            "constraintFacts": [ConstraintFact.from_dict(_item) for _item in obj["constraintFacts"]] if obj.get("constraintFacts") is not None else None,
            "constraintFactsJson": obj.get("constraintFactsJson"),
            "displayName": ComponentDisplayName.from_dict(obj["displayName"]) if obj.get("displayName") is not None else None,
            "expireWhenRemediationAvailable": obj.get("expireWhenRemediationAvailable"),
            "expiryTime": obj.get("expiryTime"),
            "hash": obj.get("hash"),
            "isObsolete": obj.get("isObsolete"),
            "matcherStrategy": obj.get("matcherStrategy"),
            "noteToReviewer": obj.get("noteToReviewer"),
            "policyId": obj.get("policyId"),
            "policyName": obj.get("policyName"),
            "policyViolationId": obj.get("policyViolationId"),
            "policyWaiverReasonId": obj.get("policyWaiverReasonId"),
            "policyWaiverRequestId": obj.get("policyWaiverRequestId"),
            "reasonText": obj.get("reasonText"),
            "rejectionReason": obj.get("rejectionReason"),
            "requestTime": obj.get("requestTime"),
            "requesterId": obj.get("requesterId"),
            "requesterName": obj.get("requesterName"),
            "reviewerId": obj.get("reviewerId"),
            "reviewerName": obj.get("reviewerName"),
            "scopeOwnerId": obj.get("scopeOwnerId"),
            "scopeOwnerName": obj.get("scopeOwnerName"),
            "scopeOwnerType": obj.get("scopeOwnerType"),
            "status": obj.get("status"),
            "threatLevel": obj.get("threatLevel"),
            "vulnerabilityId": obj.get("vulnerabilityId")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_report_policy_violation_dtov2 import ApiReportPolicyViolationDTOV2

class TestApiReportPolicyViolationDTOV2(unittest.TestCase):
    """ApiReportPolicyViolationDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiReportPolicyViolationDTOV2:
        """Test ApiReportPolicyViolationDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiReportPolicyViolationDTOV2`
        """
        model = ApiReportPolicyViolationDTOV2()
        if include_optional:
            return ApiReportPolicyViolationDTOV2(
                constraints = [
                    sonatype_iq_api_client.models.api_report_constraint_violation_dtov2.ApiReportConstraintViolationDTOV2(
                        conditions = [
                            sonatype_iq_api_client.models.api_report_constraint_condition_dtov2.ApiReportConstraintConditionDTOV2(
                                condition_reason = '', 
                                condition_summary = '', )
                            ], 
                        constraint_id = '', 
                        constraint_name = '', )
                    ],
                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grandfathered = True,
                legacy_violation = True,
                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                policy_id = '',
                policy_name = '',
                policy_threat_category = '',
                policy_threat_level = 56,
                policy_violation_id = '',
                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                waived = True,
                waived_with_auto_waiver = True
            )
        else:
            return ApiReportPolicyViolationDTOV2(
        )
        """

    def testApiReportPolicyViolationDTOV2(self):
        """Test ApiReportPolicyViolationDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_waived_policy_violation_dto import ApiWaivedPolicyViolationDTO

class TestApiWaivedPolicyViolationDTO(unittest.TestCase):
    """ApiWaivedPolicyViolationDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiWaivedPolicyViolationDTO:
        """Test ApiWaivedPolicyViolationDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiWaivedPolicyViolationDTO`
        """
        model = ApiWaivedPolicyViolationDTO()
        if include_optional:
            return ApiWaivedPolicyViolationDTO(
                constraint_violations = [
                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                        constraint_id = '', 
                        constraint_name = '', 
                        reasons = [
                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                reason = '', 
                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                    value = '', ), )
                            ], )
                    ],
                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                policy_id = '',
                policy_name = '',
                policy_violation_id = '',
                policy_waiver = sonatype_iq_api_client.models.api_policy_waiver_dto.ApiPolicyWaiverDTO(
                    associated_package_url = '', 
                    comment = '', 
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        coordinates = {
                            'key' : ''
                            }, 
                        format = '', ), 
                    component_name = '', 
                    component_upgrade_available = True, 
                    constraint_facts = [
                        sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                            condition_facts = [
                                sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                    condition_index = 56, 
                                    condition_type_id = '', 
                                    reason = '', 
                                    reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                        type = 'SECURITY_VULNERABILITY_REFID', 
                                        value = '', ), 
                                    summary = '', 
                                    trigger_json = '', )
                                ], 
                            constraint_id = '', 
                            constraint_name = '', 
                            operator_name = '', )
                        ], 
                    constraint_facts_json = '', 
                    create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    creator_id = '', 
                    creator_name = '', 
                    display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                        name = '', 
                        parts = [
                            sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                field = '', 
                                value = '', )
                            ], ), 
                    expire_when_remediation_available = True, 
                    expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    for_container_image = True, 
                    for_container_image_component = True, 
                    hash = '', 
                    is_obsolete = True, 
                    matcher_strategy = 'DEFAULT', 
                    policy_id = '', 
                    policy_name = '', 
                    policy_violation_id = '', 
                    policy_waiver_id = '', 
                    policy_waiver_reason_id = '', 
                    reason_text = '', 
                    scope_owner_id = '', 
                    scope_owner_name = '', 
                    scope_owner_type = '', 
                    threat_level = 56, 
                    vulnerability_id = '', ),
                threat_level = 56,
                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ApiWaivedPolicyViolationDTO(
        )
        """

    def testApiWaivedPolicyViolationDTO(self):
        """Test ApiWaivedPolicyViolationDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.policy_container_waiver_data_result import PolicyContainerWaiverDataResult

class TestPolicyContainerWaiverDataResult(unittest.TestCase):
    """PolicyContainerWaiverDataResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyContainerWaiverDataResult:
        """Test PolicyContainerWaiverDataResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyContainerWaiverDataResult`
        """
        model = PolicyContainerWaiverDataResult()
        if include_optional:
            return PolicyContainerWaiverDataResult(
                page = 56,
                page_count = 56,
                page_size = 56,
                results = [
                    sonatype_iq_api_client.models.policy_container_waiver_data.PolicyContainerWaiverData(
                        application_scope = '', 
                        create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        max_threat_level = 56, 
                        owner_id = '', 
                        policy_waiver_id = '', 
                        unique_component_count = 56, 
                        unique_policy_count = 56, )
                    ],
                total = 56
            )
        else:
            return PolicyContainerWaiverDataResult(
        )
        """

    def testPolicyContainerWaiverDataResult(self):
        """Test PolicyContainerWaiverDataResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_license_legal_application_report_dto import ApiLicenseLegalApplicationReportDTO

class TestApiLicenseLegalApplicationReportDTO(unittest.TestCase):
    """ApiLicenseLegalApplicationReportDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLicenseLegalApplicationReportDTO:
        """Test ApiLicenseLegalApplicationReportDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLicenseLegalApplicationReportDTO`
        """
        model = ApiLicenseLegalApplicationReportDTO()
        if include_optional:
            return ApiLicenseLegalApplicationReportDTO(
                components = [
                    sonatype_iq_api_client.models.api_license_legal_component_dto.ApiLicenseLegalComponentDTO(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        display_name = '', 
                        hash = '', 
                        license_legal_data = sonatype_iq_api_client.models.api_license_legal_data_dto.ApiLicenseLegalDataDTO(
                            attributions = [
                                sonatype_iq_api_client.models.component_obligation_attribution_dto.ComponentObligationAttributionDTO(
                                    content = '', 
                                    id = '', 
                                    last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    last_updated_by_username = '', 
                                    obligation_name = '', 
                                    owner_id = '', 
                                    package_url = '', )
                                ], 
                            component_copyright_id = '', 
                            component_copyright_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            component_copyright_last_updated_by_username = '', 
                            component_copyright_scope_owner_id = '', 
                            component_licenses_id = '', 
                            component_licenses_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            component_licenses_last_updated_by_username = '', 
                            component_licenses_scope_owner_id = '', 
                            component_notices_id = '', 
                            component_notices_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            component_notices_last_updated_by_username = '', 
                            component_notices_scope_owner_id = '', 
                            copyrights = [
                                sonatype_iq_api_client.models.api_license_legal_copyright_dto.ApiLicenseLegalCopyrightDTO(
                                    content = '', 
                                    id = '', 
                                    original_content_hash = '', 
                                    status = 'enabled', )
                                ], 
                            declared_licenses = [
                                ''
                                ], 
                            effective_license_status = '', 
                            effective_licenses = [
                                ''
                                ], 
                            highest_effective_license_threat_group = sonatype_iq_api_client.models.api_license_threat_dtov2.ApiLicenseThreatDTOV2(
                                license_threat_group_category = '', 
                                license_threat_group_level = 56, 
                                license_threat_group_name = '', ), 
                            license_files = [
                                sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                                    content = '', 
                                    id = '', 
                                    original_content_hash = '', 
                                    rel_path = '', 
                                    status = 'enabled', )
                                ], 
                            notice_files = [
                                sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                                    content = '', 
                                    id = '', 
                                    original_content_hash = '', 
                                    rel_path = '', 
                                    status = 'enabled', )
                                ], 
                            obligations = [
                                sonatype_iq_api_client.models.api_license_legal_obligation_dto.ApiLicenseLegalObligationDTO(
                                    comment = '', 
                                    id = '', 
                                    last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    last_updated_by_username = '', 
                                    name = '', 
                                    owner_id = '', 
                                    package_url = '', 
                                    status = 'OPEN', )
                                ], 
                            observed_licenses = [
                                ''
                                ], 
                            source_links = [
                                sonatype_iq_api_client.models.legal_source_link_dto.LegalSourceLinkDTO(
                                    content = '', 
                                    id = '', 
                                    original_content = '', 
                                    status = 'enabled', )
                                ], ), 
                        package_url = '', 
                        stage_scans = [
                            sonatype_iq_api_client.models.api_license_legal_stage_scan_dto.ApiLicenseLegalStageScanDTO(
                                scan_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                scan_id = '', 
                                stage_name = '', )
                            ], )
                    ],
                license_legal_metadata = [
                    sonatype_iq_api_client.models.api_license_legal_metadata_dto.ApiLicenseLegalMetadataDTO(
                        is_multi = True, 
                        license_id = '', 
                        license_name = '', 
                        license_text = '', 
                        obligations = [
                            sonatype_iq_api_client.models.license_obligation_dto.LicenseObligationDTO(
                                name = '', 
                                obligation_texts = [
                                    ''
                                    ], )
                            ], 
                        single_license_ids = [
                            ''
                            ], 
                        threat_group = sonatype_iq_api_client.models.license_threat_group_dto.LicenseThreatGroupDTO(
                            name = '', 
                            threat_level = 56, ), )
                    ]
            )
        else:
            return ApiLicenseLegalApplicationReportDTO(
        )
        """

    def testApiLicenseLegalApplicationReportDTO(self):
        """Test ApiLicenseLegalApplicationReportDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Optional
from typing_extensions import Annotated

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class SPDXApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_by_scan_id(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_by_scan_id_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_by_scan_id_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_by_scan_id_serialize(
        self,
        application_id,
        scan_id,
        format,
        generate_cyclone_dx,
        spdx_version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if scan_id is not None:
            _path_params['scanId'] = scan_id
        # process the query parameters
        if format is not None:
            
            _query_params.append(('format', format))
            
        if generate_cyclone_dx is not None:
            
            _query_params.append(('generateCycloneDx', generate_cyclone_dx))
            
        if spdx_version is not None:
            
            _query_params.append(('spdxVersion', spdx_version))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/octet-stream', 
                    'application/xml'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/spdx/{applicationId}/reports/{scanId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_latest_for_stage(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_latest_for_stage_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_latest_for_stage_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_latest_for_stage_serialize(
        self,
        application_id,
        stage_id,
        format,
        generate_cyclone_dx,
        spdx_version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if stage_id is not None:
            _path_params['stageId'] = stage_id
        # process the query parameters
        if format is not None:
            
            _query_params.append(('format', format))
            
        if generate_cyclone_dx is not None:
            
            _query_params.append(('generateCycloneDx', generate_cyclone_dx))
            
        if spdx_version is not None:
            
            _query_params.append(('spdxVersion', spdx_version))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/octet-stream', 
                    'application/xml'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/spdx/{applicationId}/stages/{stageId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_report_raw_data_dtov2 import ApiReportRawDataDTOV2

class TestApiReportRawDataDTOV2(unittest.TestCase):
    """ApiReportRawDataDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiReportRawDataDTOV2:
        """Test ApiReportRawDataDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiReportRawDataDTOV2`
        """
        model = ApiReportRawDataDTOV2()
        if include_optional:
            return ApiReportRawDataDTOV2(
                components = [
                    sonatype_iq_api_client.models.api_report_component_dtov2.ApiReportComponentDTOV2(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        cpe = '', 
                        dependency_data = sonatype_iq_api_client.models.api_dependency_data_dto.ApiDependencyDataDTO(
                            direct_dependency = True, 
                            inner_source = True, 
                            inner_source_data = [
                                sonatype_iq_api_client.models.inner_source_data.InnerSourceData(
                                    inner_source_component_purl = '', 
                                    owner_application_id = '', 
                                    owner_application_name = '', )
                                ], 
                            parent_component_purls = [
                                ''
                                ], ), 
                        display_name = '', 
                        filenames = [
                            ''
                            ], 
                        hash = '', 
                        identification_source = '', 
                        license_data = sonatype_iq_api_client.models.api_license_data_dtov2.ApiLicenseDataDTOV2(
                            declared_licenses = [
                                sonatype_iq_api_client.models.api_license_dto.ApiLicenseDTO(
                                    license_id = '', 
                                    license_name = '', )
                                ], 
                            effective_license_threats = [
                                sonatype_iq_api_client.models.api_license_threat_dtov2.ApiLicenseThreatDTOV2(
                                    license_threat_group_category = '', 
                                    license_threat_group_level = 56, 
                                    license_threat_group_name = '', )
                                ], 
                            effective_licenses = [
                                sonatype_iq_api_client.models.api_license_dto.ApiLicenseDTO(
                                    license_id = '', 
                                    license_name = '', )
                                ], 
                            observed_licenses = [
                                
                                ], 
                            overridden_licenses = [
                                
                                ], 
                            status = '', ), 
                        match_state = '', 
                        package_url = '', 
                        pathnames = [
                            ''
                            ], 
                        proprietary = True, 
                        security_data = sonatype_iq_api_client.models.api_security_data_dto.ApiSecurityDataDTO(
                            security_issues = [
                                sonatype_iq_api_client.models.api_security_issue_dto.ApiSecurityIssueDTO(
                                    analysis = sonatype_iq_api_client.models.api_security_issue_analysis_dto.ApiSecurityIssueAnalysisDTO(
                                        detail = '', 
                                        justification = '', 
                                        response = '', 
                                        state = '', ), 
                                    cvss_vector = '', 
                                    cvss_vector_source = '', 
                                    cwe = '', 
                                    reference = '', 
                                    severity = 1.337, 
                                    source = '', 
                                    status = '', 
                                    threat_category = '', 
                                    url = '', )
                                ], ), 
                        sha256 = '', 
                        swid = sonatype_iq_api_client.models.swid.Swid(
                            name = '', 
                            patch = True, 
                            tag_id = '', 
                            tag_version = 56, 
                            text = sonatype_iq_api_client.models.attachment_text.AttachmentText(
                                content = '', 
                                content_type = '', 
                                encoding = '', ), 
                            version = '', ), 
                        third_party = True, )
                    ],
                global_information = sonatype_iq_api_client.models.api_global_information_dtov2.ApiGlobalInformationDTOV2(
                    data_version_date = '', ),
                match_summary = sonatype_iq_api_client.models.api_match_state_summary_dtov2.ApiMatchStateSummaryDTOV2(
                    known_component_count = 56, 
                    total_component_count = 56, )
            )
        else:
            return ApiReportRawDataDTOV2(
        )
        """

    def testApiReportRawDataDTOV2(self):
        """Test ApiReportRawDataDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
